@@ -21,6 +21,7 @@ import jwt
 import munch
 import requests
 from argon2 import PasswordHasher
+from botocore.exceptions import ClientError
 from dateutil import parser
 from hvac.exceptions import Forbidden
 from jinja2 import Environment, BaseLoader
@@ -532,7 +533,6 @@ def get_vault_configuration(*, kms_region, role_id, secret_id, address, path):
     for env_var, mapped_var in env_vars.items():
         if env_var in os.environ:
             pass
-    # kms_region = os.environ['PROBATOR_KMS_REGION'] if 'PROBATOR'
 
     try:
         session = get_local_aws_session()
@@ -558,6 +558,30 @@ def get_vault_configuration(*, kms_region, role_id, secret_id, address, path):
         log.exception('Failed reading data from Vault, unable to authenticate')
 
 
+def get_secrets_manager_configuration(*, secret_id, region):
+    """Retrieve and update the application configuration with information from AWS Secrets Manager
+
+    Args:
+        secret_id (str): Secret ID to load
+        region (str): AWS region for Secrets Manager
+
+    Returns:
+        `munch.Munch`
+    """
+    from probator import get_local_aws_session
+
+    session = get_local_aws_session()
+    sm = session.client('secretsmanager', region_name=region)
+    try:
+        res = sm.get_secret_value(SecretId=secret_id)
+        if res and 'SecretString' in res:
+            return munch.munchify(json.loads(res['SecretString']))
+        else:
+            raise ProbatorError('Invalid or empty secret id in AWS Secrets Manager')
+    except ClientError as ex:
+        log.warning(f'Failed loading configuration from AWS Secrets Manager: {ex}')
+
+
 def read_config():
     """Attempts to read the application configuration file and will raise a `FileNotFoundError` if the
     configuration file is not found. Returns the folder where the configuration file was loaded from, and
